@@ -19,6 +19,7 @@ from pytwin.settings import (
     PyTwinLogOption,
     PyTwinSettingsError,
     get_pytwin_log_file,
+    get_pytwin_log_level,
     get_pytwin_logger,
     get_pytwin_working_dir,
     modify_pytwin_logging,
@@ -27,6 +28,7 @@ from pytwin.settings import (
 )
 
 PYTWIN_LOG_DEBUG = PyTwinLogLevel.PYTWIN_LOG_DEBUG
+PYTWIN_LOG_INFO = PyTwinLogLevel.PYTWIN_LOG_INFO
 PYTWIN_LOG_WARNING = PyTwinLogLevel.PYTWIN_LOG_WARNING
 PYTWIN_LOG_ERROR = PyTwinLogLevel.PYTWIN_LOG_ERROR
 PYTWIN_LOG_CRITICAL = PyTwinLogLevel.PYTWIN_LOG_CRITICAL
